<?php
 
class SocialMag_Ad_Widget extends WP_Widget {

public function __construct() {
	$socialmag_ad_widget = array(
		'classname' => 'socialmag_ad_widget',
		'description' => esc_html__('Custom Ad image with link', 'socialmag'),
		'customize_selective_refresh' => true,
	);
		parent::__construct( 'socialmag_ad_widget', esc_html__('Custom Ad', 'socialmag'), $socialmag_ad_widget );
	}
    
	// Render widget on front end and set defaults
	function widget($args, $instance) {
		        
		$instance = wp_parse_args( (array) $instance, array(
			'before_title'  => '<h3>',
			'after_title'   => '</h3>',
			'before_widget' => '<div class="socialmag-theme-widget">',
			'after_widget'  => '</div>',
			'title' => esc_html__('Custom Ad', 'socialmag'),
			'socialmag_ad_image' => esc_url( get_template_directory_uri() .'/images/socialmag-ad-widget.jpg' ),
			'socialmag_ad_alt_text' => esc_attr( 'ad image' ),
			'socialmag_ad_url' => esc_url( '#' ),
			'socialmag_ad_tab' => 0,
		));
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$socialmag_ad_image = esc_url($instance['socialmag_ad_image']);
		$socialmag_ad_alt_text = $instance['socialmag_ad_alt_text'];
		$socialmag_ad_url = esc_url($instance['socialmag_ad_url']);
		$socialmag_ad_tab = intval($instance['socialmag_ad_tab']);

		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title']; ?>
		
		<div class="socialmag-ad-widget">
		<?php if ( $socialmag_ad_image != '' ): ?>
			<a href="<?php echo esc_url( $socialmag_ad_url ); ?>" <?php if( $socialmag_ad_tab != 0 ): ?>target="_blank"<?php endif; ?> ><img class="socialmag-ad-image" src="<?php echo esc_url( $socialmag_ad_image ); ?>" width="300" alt="<?php echo esc_attr($socialmag_ad_alt_text); ?>" /></a>
		<?php endif; ?>
		</div><!-- socialmag-ad-widget -->

		<?php echo $args['after_widget'];
	}
	
	// Update new instances from old instances
	function update($new_instance, $old_instance) {
        $instance = $old_instance;

        $instance['title']                    	= ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['socialmag_ad_image']       	= ( ! empty( $new_instance['socialmag_ad_image'] ) ) ? wp_kses_post($new_instance['socialmag_ad_image']) : '';
        $instance['socialmag_ad_alt_text'] 		= ( ! empty( $new_instance['socialmag_ad_alt_text'] ) ) ? sanitize_text_field($new_instance['socialmag_ad_alt_text']) : '';
        $instance['socialmag_ad_url']           = ( ! empty( $new_instance['socialmag_ad_url'] ) ) ? esc_url_raw($new_instance['socialmag_ad_url']) : '';
        $instance['socialmag_ad_tab']     		= ( ! empty( $new_instance['socialmag_ad_tab'] ) ) ? intval($new_instance['socialmag_ad_tab'] = 1 ) : '';

        return $new_instance;
    }
	
	//Render widget form on back end with set defaults
	function form($instance) {
		$instance = wp_parse_args( (array) $instance, array(
			'socialmag_ad_image' => esc_url( get_template_directory_uri() .'/images/socialmag-ad-widget.jpg' ),
			'socialmag_ad_alt_text' => esc_attr( 'ad image' ),
			'socialmag_ad_url' => esc_url( '#' ),
			'socialmag_ad_tab' => esc_html__('Read More', 'socialmag'),
		));
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$socialmag_ad_image = isset( $instance['socialmag_ad_image'] ) ? esc_url($instance['socialmag_ad_image']) : '';
		$socialmag_ad_alt_text = isset( $instance['socialmag_ad_alt_text'] ) ? esc_attr($instance['socialmag_ad_alt_text']) : '';
		$socialmag_ad_url = isset( $instance['socialmag_ad_url'] ) ? esc_url($instance['socialmag_ad_url']) : '';
		$socialmag_ad_tab = isset( $instance['socialmag_ad_tab'] ) ? intval($instance['socialmag_ad_tab']) : '';
		
		if ( isset( $instance[ 'title' ] ) ) {
		$title = $instance[ 'title' ];
		}
		else {
		$title = esc_html__( 'Ad Widget', 'socialmag' );
		} ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'socialmag' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		
		<img class="socialmag-ad-image" src="<?php echo esc_url( $socialmag_ad_image ); ?>" width="300" />
		<p>
			<label for="<?php echo $this->get_field_id('socialmag_ad_image'); ?>"><?php _e('Ad Image URL:', 'socialmag'); ?> </label>
			<input class="widefat" id="<?php echo $this->get_field_id('socialmag_ad_image'); ?>" name="<?php echo $this->get_field_name('socialmag_ad_image'); ?>" type="url" value="<?php echo esc_url($socialmag_ad_image); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('socialmag_ad_alt_text'); ?>"><?php _e('Ad Image Alt Text:', 'socialmag'); ?> </label>
			<input class="widefat" id="<?php echo $this->get_field_id('socialmag_ad_alt_text'); ?>" name="<?php echo $this->get_field_name('socialmag_ad_alt_text'); ?>" type="text" value="<?php echo esc_attr($socialmag_ad_alt_text); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('socialmag_ad_url'); ?>"><?php _e('Ad Destination URL:', 'socialmag'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('socialmag_ad_url'); ?>" name="<?php echo $this->get_field_name('socialmag_ad_url'); ?>" type="url" value="<?php echo esc_url( $socialmag_ad_url ); ?>" />
		</p>
		<p>
            <input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('socialmag_ad_tab'); ?>" name="<?php echo $this->get_field_name('socialmag_ad_tab'); ?>" <?php checked( true , $socialmag_ad_tab ); ?> />
            <label for="<?php echo $this->get_field_id('socialmag_ad_tab'); ?>">
                <?php _e( 'Open Ad in New Tab', 'socialmag' ); ?>
            </label>
        </p>
			
	<?php }
	
} // ends widget class SocialMag_Ad_Widget